===============
django-inviter2
===============

.. image:: https://travis-ci.org/mjschultz/django-inviter2.svg?branch=master
    :target: https://travis-ci.org/mjschultz/django-inviter2
    :alt: Build status

.. image:: https://coveralls.io/repos/mjschultz/django-inviter2/badge.png?branch=master
    :target: https://coveralls.io/r/mjschultz/django-inviter2?branch=master
    :alt: Coverage status

Let your users invite new users.

Useful if you want your webapp to be in a private beta mode or for only permitting access to known users.

Installation
============

    $ pip install django-inviter2

Version Support
===============

- Django 1.4, 1.5, and 1.6 (requires Python 2.6 or 2.7)
- Django 1.5 and 1.6 (requires Python 2.6, 2.7, 3.2, 3.3, or 3.4)
- Django 1.7b3 (requires Python 2.7, 3.2, 3.3, or 3.4)

History
=======

This is a fork of django-inviter_.

.. _django-inviter: http://www.caffeinehit.com/work/code/django-inviter


Documentation is available via `Read the Docs`_

.. _Read the Docs: http://django-inviter2.readthedocs.org/
